@@ -47,13 +47,6 @@ extern "C" {
 #include "control.h"
 #include "pcm.h"
 #include "mixer.h"
-#include "rawmidi.h"
-#include "hwdep.h"
-#include "timer.h"
-#include "conf.h"
-#include "seq_event.h"
-#include "seq.h"
-#include "seqmid.h"
 
 #ifdef __cplusplus
 }
