@@ -38,6 +38,8 @@ int snd_pcm_hw_params_get_min_align(const snd_pcm_hw_params_t *params,
 int snd_pcm_sw_params(snd_pcm_t *pcm, snd_pcm_sw_params_t *params);
 
 snd_pcm_sframes_t snd_pcm_avail_update(snd_pcm_t *pcm);
+int snd_pcm_avail_delay(snd_pcm_t *pcm, snd_pcm_sframes_t *availp,
+			snd_pcm_sframes_t *delayp);
 snd_pcm_sframes_t snd_pcm_writei(snd_pcm_t *pcm, const void *buffer,
 				 snd_pcm_uframes_t size);
 snd_pcm_sframes_t snd_pcm_readi(snd_pcm_t *pcm, void *buffer,
